Learn R Programming

GeoFIS (version 1.1.1)

GeoFIS: GeoFIS package

Description

GeoFIS is an open source software that provides methods for processing spatial data for decision making through a user-friendly interface agriculture8060073GeoFIS.
This R package implements two main functionalities: management zone delineation Pedroso10GeoFIS and data aggregation denys20-ascii,gistam20GeoFIS. All the mentioned publications are available from the GeoFIS web site.

Arguments

Author

GeoFIS Team contact@geofis.org

References

agriculture8060073GeoFISfuzzieee12geofisGeoFISijcis13GeoFISPedroso10GeoFISdenys20-asciiGeoFISgistam20GeoFIS

See Also